@@ -362,7 +362,7 @@ tmx_show <- function(model, what = c("values", "free", "labels", "nonzero_or_fre
 				cols = dim(values)[[2]]
 				tb = kbl(values, caption = paste0(w, " matrix"))
 				tb = add_footnote(tb, label = paste0("Fixed cells in gray, free in black, mouse-over to see labels, paths fixed@0 are shown as ", omxQuotes(zero.print))) # , paths fixed@0 left blank
-				tb = xmu_style_kable(tb, html_font = html_font, bootstrap_options= bootstrap_options, lightable_options = lightable_options, full_width = FALSE)
+				tb = xmu_style_kable(tb, style = style, html_font = html_font, bootstrap_options= bootstrap_options, lightable_options = lightable_options, full_width = FALSE)
 				
 				for (thisCol in 2:(cols+1)) {
 					tb = column_spec(tb, thisCol, 
